// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Text;
using System.Collections.Generic;
using System.Security.Cryptography;
using System.Security.Cryptography.X509Certificates;

using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Pdf.Security;
using GrapeCity.Documents.Pdf.AcroForms;
using GrapeCity.Documents.Text;


namespace DsPdfWeb.Demos
{
    // このサンプルでは、PKCS #12（Public Key Cryptography Standard #12）にて
    // 暗号化された電子証明書を含む .p12 ファイルを使用して、
    // PDF に署名する方法を示しています。
    public class SignWithP12
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            using var s = File.OpenRead(Path.Combine("Resources", "PDFs", "SignWithP12.pdf"));
            doc.Load(s);

            var p12 = Path.Combine("Resources", "Misc", "GcPdfTest2KeyStore.p12");
            var sp = new SignatureProperties()
            {
                SignatureBuilder = new Pkcs7SignatureBuilder()
                {
                    CertificateChain = SecurityUtils.GetCertificateChain(p12, "qq"),
                },
                SignatureField = doc.AcroForm.Fields[0],
            };
            sp.SignatureAppearance.Caption = "PKCS #12";
            doc.Sign(sp, stream);

            // 終了
            return doc.Pages.Count;
        }
    }
}
